@@ -25,7 +25,7 @@ from fanstatic import Library, Resource
 
 # import local packages
 from ztfy.blog.browser import ztfy_blog_back
-from ztfy.jqueryui import jquery_alerts, jquery_jsonrpc
+from ztfy.jqueryui import jquery_alerts, jquery_jsonrpc, jquery_color
 
 
 library = Library('ztfy.thesaurus', 'resources')
@@ -34,6 +34,6 @@ ztfy_thesaurus_css = Resource(library, 'css/ztfy.thesaurus.css')
 
 ztfy_thesaurus = Resource(library, 'js/ztfy.thesaurus.js',
                           minified='js/ztfy.thesaurus.min.js',
-                          depends=[ztfy_blog_back, jquery_alerts, jquery_jsonrpc,
+                          depends=[ztfy_blog_back, jquery_alerts, jquery_jsonrpc, jquery_color,
                                    ztfy_thesaurus_css],
                           bottom=True)
