@@ -32,6 +32,7 @@ from ztfy.blog.browser.interfaces.container import ITitleColumn, IActionsColumn,
 from ztfy.security.interfaces import ISecurityManager
 from ztfy.skin.interfaces import IContainedDefaultView, IContainerBaseView, IDefaultView
 from ztfy.skin.layer import IZTFYBrowserLayer, IZTFYBackLayer
+from ztfy.thesaurus.browser.interfaces import IThesaurusView
 from ztfy.thesaurus.browser.interfaces.thesaurus import IThesaurusAddFormMenuTarget, \
                                                         IThesaurusExtractAddFormMenuTarget
 from ztfy.thesaurus.interfaces.loader import IThesaurusLoader, IThesaurusLoaderConfiguration, \
@@ -42,7 +43,6 @@ from ztfy.thesaurus.interfaces.thesaurus import IThesaurusInfoBase, IThesaurusIn
                                                 IThesaurusRoles, \
                                                 IThesaurusExtracts, IThesaurusExtractBaseInfo, IThesaurusExtractInfo
 
-
 # import Zope3 packages
 from z3c.form import field, button
 from z3c.form.browser.select import SelectWidget
@@ -62,8 +62,7 @@ from zope.traversing import api as traversing_api
 from zope.traversing.browser import absoluteURL
 
 # import local packages
-from ztfy.jqueryui import jquery_multiselect, jquery_colorpicker, \
-    jquery_datetime
+from ztfy.jqueryui import jquery_multiselect, jquery_colorpicker, jquery_datetime
 from ztfy.security.browser.roles import RolesEditForm
 from ztfy.skin.container import ContainerBaseView
 from ztfy.skin.form import DialogAddForm, EditForm, DialogEditForm
@@ -97,6 +96,14 @@ class ThesaurusBackViewAdapter(object):
         return '%s/%s' % (absoluteURL(self.context, self.request), self.viewname)
 
 
+class ThesaurusManagerTargetBackViewAdapter(ThesaurusBackViewAdapter):
+    """Thesaurus target default back-office view adapter"""
+
+    adapts(IThesaurusManagerTarget, IZTFYBackLayer, IThesaurusView)
+
+    viewname = '@@thesaurus.html'
+
+
 class ThesaurusListViewMenu(MenuItem):
     """Thesaurus list view menu"""
 
@@ -137,7 +144,7 @@ class ThesaurusListViewTitleCellAdapter(object):
 class ThesaurusListView(ajax.AJAXRequestHandler, ContainerBaseView):
     """Actual list of available thesauri"""
 
-    implements(IThesaurusAddFormMenuTarget)
+    implements(IThesaurusView, IThesaurusAddFormMenuTarget)
 
     legend = _("List of registered thesauri")
     output = ContainerBaseView.render
@@ -273,6 +280,8 @@ class ThesaurusImportMenuItem(DialogMenuItem):
 class ThesaurusEditForm(EditForm):
     """Thesaurus edit form"""
 
+    implements(IThesaurusView)
+
     legend = _("Edit thesaurus properties")
 
     fields = field.Fields(IThesaurusInfo).select('name', 'title', 'subject', 'description', 'language',
@@ -399,7 +408,7 @@ class ThesaurusExtractsListViewCellActions(object):
 class ThesaurusExtractsListView(ContainerBaseView):
     """Thesaurus extracts list view"""
 
-    implements(IThesaurusExtractAddFormMenuTarget)
+    implements(IThesaurusView, IThesaurusExtractAddFormMenuTarget)
 
     legend = _("List of thesaurus extracts")
     output = ContainerBaseView.render
