@@ -100,8 +100,8 @@ class ThesaurusTerm(Persistent, Contained):
     @generic.setter
     def generic(self, value):
         self._generic = generic = removeSecurityProxy(value)
-        if (generic is not None) and generic.extracts:
-            self.extracts = (self.extracts or set()) & generic.extracts
+        if generic is not None:
+            self.extracts = self.extracts & generic.extracts
 
     @property
     def specifics(self):
@@ -125,7 +125,10 @@ class ThesaurusTerm(Persistent, Contained):
 
     @usage.setter
     def usage(self, value):
-        self._usage = removeSecurityProxy(value)
+        self._usage = usage = removeSecurityProxy(value)
+        if usage is not None:
+            self.generic = None
+            self.extracts = usage.extracts
 
     @property
     def used_for(self):
@@ -162,6 +165,9 @@ class ThesaurusTerm(Persistent, Contained):
             self.extracts = (self.extracts or set()) | set((extract,))
         else:
             self._extracts = removeSecurityProxy((self._extracts or set()) | set((extract,)))
+            # Extracts selection also applies to term synonyms...
+            for term in self.used_for or ():
+                term.extracts = self.extracts
 
     def removeExtract(self, extract, check=True):
         if IThesaurusExtractInfo.providedBy(extract):
@@ -170,6 +176,9 @@ class ThesaurusTerm(Persistent, Contained):
             self.extracts = (self.extracts or set()) - set((extract,))
         else:
             self._extracts = removeSecurityProxy((self._extracts or set()) - set((extract,)))
+            # Extracts selection also applies to term synonyms...
+            for term in self.used_for or ():
+                term.extracts = self.extracts
 
     @property
     def extensions(self):
